package com.ruoyi.frequency.platformrulestype.service;

import java.util.List;
import com.ruoyi.frequency.platformrulestype.entity.PlatformRulesType;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 平台规则类型Service接口
 * 
 * @author liwenlong
 * @date 2024-02-23
 */
public interface PlatformRulesTypeService extends IService<PlatformRulesType>
{
    /**
     * 查询平台规则类型
     * 
     * @param id 平台规则类型主键
     * @return 平台规则类型
     */
    public PlatformRulesType selectPlatformRulesTypeById(Long id);

    /**
     * 查询平台规则类型列表
     * 
     * @param platformRulesType 平台规则类型
     * @return 平台规则类型集合
     */
    public List<PlatformRulesType> selectPlatformRulesTypeList(PlatformRulesType platformRulesType);

    /**
     * 新增平台规则类型
     * 
     * @param platformRulesType 平台规则类型
     * @return 结果
     */
    public int insertPlatformRulesType(PlatformRulesType platformRulesType);

    /**
     * 修改平台规则类型
     * 
     * @param platformRulesType 平台规则类型
     * @return 结果
     */
    public int updatePlatformRulesType(PlatformRulesType platformRulesType);

    /**
     * 批量删除平台规则类型
     * 
     * @param ids 需要删除的平台规则类型主键集合
     * @return 结果
     */
    public int deletePlatformRulesTypeByIds(Long[] ids,Integer delFlag);

}
